@@ -91,7 +91,7 @@ class Locker:
         self.fp.close()
 
 
-def create_airflow_connections(connections):
+def _create_airflow_connections(connections):
     with create_session() as session:
         for connection in connections:
             if session.query(Connection).filter(Connection.conn_id == connection.conn_id).first():
@@ -105,15 +105,14 @@ def create_airflow_connections(connections):
             logging.info(f"Imported connection {connection.conn_id}")
 
 
-def contains_duplicate_task_names(dag_bag, refresh_from_airflow_db):
+def _contains_duplicate_task_names(dag_bag):
     check.inst_param(dag_bag, "dag_bag", DagBag)
-    check.bool_param(refresh_from_airflow_db, "refresh_from_airflow_db")
     seen_task_names = set()
 
     # To enforce predictable iteration order
     sorted_dag_ids = sorted(dag_bag.dag_ids)
     for dag_id in sorted_dag_ids:
-        dag = dag_bag.dags.get(dag_id) if not refresh_from_airflow_db else dag_bag.get_dag(dag_id)
+        dag = dag_bag.dags.get(dag_id)
         for task in dag.tasks:
             if task.task_id in seen_task_names:
                 return True
@@ -122,34 +121,17 @@ def contains_duplicate_task_names(dag_bag, refresh_from_airflow_db):
     return False
 
 
-def make_dagster_repo_from_airflow_dag_bag(
+def _make_schedules_and_jobs_from_airflow_dag_bag(
     dag_bag,
-    repo_name,
-    refresh_from_airflow_db=False,
     use_airflow_template_context=False,
     mock_xcom=False,
-    use_ephemeral_airflow_db=False,
+    use_ephemeral_airflow_db=True,
     connections=None,
 ):
-    """Construct a Dagster repository corresponding to Airflow DAGs in DagBag.
-
-    Usage:
-        Create `make_dagster_repo.py`:
-            from dagster_airflow.dagster_pipeline_factory import make_dagster_repo_from_airflow_dag_bag
-            from airflow_home import my_dag_bag
-
-            def make_repo_from_dag_bag():
-                return make_dagster_repo_from_airflow_dag_bag(my_dag_bag, 'my_repo_name')
-
-        Use RepositoryDefinition as usual, for example:
-            `dagit -f path/to/make_dagster_repo.py -n make_repo_from_dag_bag`
+    """Construct Dagster Schedules and Jobs corresponding to Airflow DagBag.
 
     Args:
-        dag_path (str): Path to directory or file that contains Airflow Dags
-        repo_name (str): Name for generated RepositoryDefinition
-        refresh_from_airflow_db (bool): If True, will refresh DAG if expired via DagBag.get_dag(),
-            which requires access to initialized Airflow DB. If False (recommended), gets dag from
-            DagBag's dags dict without depending on Airflow DB. (default: False)
+        dag_bag (DagBag): Airflow DagBag Model
         use_airflow_template_context (bool): If True, will call get_template_context() on the
             Airflow TaskInstance model which requires and modifies the DagRun table. The use_airflow_template_context
             setting is ignored if use_ephemeral_airflow_db is True.
@@ -162,11 +144,10 @@ def make_dagster_repo_from_airflow_dag_bag(
             Airflow DB, if use_emphemeral_airflow_db is False this will be ignored.
 
     Returns:
-        RepositoryDefinition
+        - List[ScheduleDefinition]: The generated Dagster Schedules
+        - List[JobDefinition]: The generated Dagster Jobs
     """
     check.inst_param(dag_bag, "dag_bag", DagBag)
-    check.str_param(repo_name, "repo_name")
-    check.bool_param(refresh_from_airflow_db, "refresh_from_airflow_db")
     check.bool_param(use_airflow_template_context, "use_airflow_template_context")
     mock_xcom = check.opt_bool_param(mock_xcom, "mock_xcom")
     use_ephemeral_airflow_db = check.opt_bool_param(
@@ -174,17 +155,15 @@ def make_dagster_repo_from_airflow_dag_bag(
     )
     connections = check.opt_list_param(connections, "connections", of_type=Connection)
 
-    use_unique_id = contains_duplicate_task_names(dag_bag, refresh_from_airflow_db)
+    use_unique_id = _contains_duplicate_task_names(dag_bag)
 
     job_defs = []
     schedule_defs = []
-    asset_defs = []
     count = 0
     # To enforce predictable iteration order
     sorted_dag_ids = sorted(dag_bag.dag_ids)
     for dag_id in sorted_dag_ids:
-        # Only call Airflow DB via dag_bag.get_dag(dag_id) if refresh_from_airflow_db is True
-        dag = dag_bag.dags.get(dag_id) if not refresh_from_airflow_db else dag_bag.get_dag(dag_id)
+        dag = dag_bag.dags.get(dag_id)
         if not use_unique_id:
             pipeline_def = make_dagster_pipeline_from_airflow_dag(
                 dag=dag,
@@ -218,17 +197,72 @@ def make_dagster_repo_from_airflow_dag_bag(
             dag=dag,
             job_def=job_def,
         )
-        asset_def = make_dagster_asset_from_airflow_dag(dag=dag, job_def=job_def)
         if schedule_def:
             schedule_defs.append(schedule_def)
-        elif asset_def:
-            asset_defs.append(asset_def)
         else:
             job_defs.append(job_def)
 
+    return schedule_defs, job_defs
+
+
+def make_dagster_repo_from_airflow_dag_bag(
+    dag_bag,
+    repo_name,
+    use_airflow_template_context=False,
+    mock_xcom=False,
+    use_ephemeral_airflow_db=False,
+    connections=None,
+):
+    """Construct a Dagster repository corresponding to Airflow DAGs in DagBag.
+
+    Usage:
+        Create `make_dagster_repo.py`:
+            from dagster_airflow.dagster_pipeline_factory import make_dagster_repo_from_airflow_dag_bag
+            from airflow_home import my_dag_bag
+
+            def make_repo_from_dag_bag():
+                return make_dagster_repo_from_airflow_dag_bag(my_dag_bag, 'my_repo_name')
+
+        Use RepositoryDefinition as usual, for example:
+            `dagit -f path/to/make_dagster_repo.py -n make_repo_from_dag_bag`
+
+    Args:
+        dag_bag (DagBag): Airflow DagBag Model
+        repo_name (str): Name for generated RepositoryDefinition
+        use_airflow_template_context (bool): If True, will call get_template_context() on the
+            Airflow TaskInstance model which requires and modifies the DagRun table. The use_airflow_template_context
+            setting is ignored if use_ephemeral_airflow_db is True.
+            (default: False)
+        mock_xcom (bool): If True, dagster will mock out all calls made to xcom, features that
+            depend on xcom may not work as expected. (default: False)
+        use_ephemeral_airflow_db (bool): If True, dagster will create an ephemeral sqlite airflow
+            database for each run. (default: False)
+        connections (List[Connection]): List of Airflow Connections to be created in the Ephemeral
+            Airflow DB, if use_emphemeral_airflow_db is False this will be ignored.
+
+    Returns:
+        RepositoryDefinition
+    """
+    check.inst_param(dag_bag, "dag_bag", DagBag)
+    check.str_param(repo_name, "repo_name")
+    check.bool_param(use_airflow_template_context, "use_airflow_template_context")
+    mock_xcom = check.opt_bool_param(mock_xcom, "mock_xcom")
+    use_ephemeral_airflow_db = check.opt_bool_param(
+        use_ephemeral_airflow_db, "use_ephemeral_airflow_db"
+    )
+    connections = check.opt_list_param(connections, "connections", of_type=Connection)
+
+    schedules, jobs = _make_schedules_and_jobs_from_airflow_dag_bag(
+        dag_bag,
+        use_airflow_template_context,
+        mock_xcom,
+        use_ephemeral_airflow_db,
+        connections,
+    )
+
     @repository(name=repo_name)
     def _repo():
-        return [job_defs, schedule_defs]
+        return [jobs, schedules]
 
     return _repo
 
@@ -255,38 +289,11 @@ def make_dagster_schedule_from_airflow_dag(dag, job_def):
         )
 
 
-def make_dagster_asset_from_airflow_dag(dag, job_def):
-    """Construct a Dagster asset corresponding to an Airflow DAG.
-
-    Args:
-        dag (DAG): Airflow DAG
-        job_def (JobDefinition): Dagster pipeline corresponding to Airflow DAG
-
-    Returns:
-        AssetDefinition
-    """
-    check.inst_param(dag, "dag", DAG)
-    check.inst_param(job_def, "job_def", JobDefinition)
-
-    cron_schedule = dag.normalized_schedule_interval
-    if isinstance(dag.normalized_schedule_interval, str) and cron_schedule == "Dataset":
-        # TODO: add support for asset tags
-        return
-
-
 def make_dagster_repo_from_airflow_example_dags(
     repo_name="airflow_example_dags_repo", use_ephemeral_airflow_db=True
 ):
     """Construct a Dagster repository for Airflow's example DAGs.
 
-    Execution of the following Airflow example DAGs is not currently supported:
-            'example_external_task_marker_child',
-            'example_pig_operator',
-            'example_skip_dag',
-            'example_trigger_target_dag',
-            'example_xcom',
-            'test_utils',
-
     Usage:
 
         Create `make_dagster_repo.py`:
@@ -301,7 +308,7 @@ def make_dagster_repo_from_airflow_example_dags(
     Args:
         repo_name (str): Name for generated RepositoryDefinition
         use_ephemeral_airflow_db (bool): If True, dagster will create an ephemeral sqlite airflow
-            database for each run. (default: False)
+            database for each run. (default: True)
 
     Returns:
         RepositoryDefinition
@@ -324,7 +331,6 @@ def make_dagster_repo_from_airflow_dags_path(
     dag_path,
     repo_name,
     safe_mode=True,
-    store_serialized_dags=False,
     use_airflow_template_context=False,
     mock_xcom=False,
     use_ephemeral_airflow_db=True,
@@ -332,8 +338,6 @@ def make_dagster_repo_from_airflow_dags_path(
 ):
     """Construct a Dagster repository corresponding to Airflow DAGs in dag_path.
 
-    ``DagBag.get_dag()`` dependency requires Airflow DB to be initialized.
-
     Usage:
         Create ``make_dagster_repo.py``:
 
@@ -355,8 +359,6 @@ def make_dagster_repo_from_airflow_dags_path(
         include_examples (bool): True to include Airflow's example DAGs. (default: False)
         safe_mode (bool): True to use Airflow's default heuristic to find files that contain DAGs
             (ie find files that contain both b'DAG' and b'airflow') (default: True)
-        store_serialized_dags (bool): True to read Airflow DAGS from Airflow DB. False to read DAGS
-            from Python files. (default: False)
         use_airflow_template_context (bool): If True, will call get_template_context() on the
             Airflow TaskInstance model which requires and modifies the DagRun table. The use_airflow_template_context
             setting is ignored if use_ephemeral_airflow_db is True.
@@ -374,15 +376,14 @@ def make_dagster_repo_from_airflow_dags_path(
     check.str_param(dag_path, "dag_path")
     check.str_param(repo_name, "repo_name")
     check.bool_param(safe_mode, "safe_mode")
-    check.bool_param(store_serialized_dags, "store_serialized_dags")
     check.bool_param(use_airflow_template_context, "use_airflow_template_context")
     mock_xcom = check.opt_bool_param(mock_xcom, "mock_xcom")
     use_ephemeral_airflow_db = check.opt_bool_param(
         use_ephemeral_airflow_db, "use_ephemeral_airflow_db"
     )
     connections = check.opt_list_param(connections, "connections", of_type=Connection)
-    # add connections as environment variables so that dag evaluation works
-    create_airflow_connections(connections)
+    # add connections to airflow so that dag evaluation works
+    _create_airflow_connections(connections)
     try:
         dag_bag = DagBag(
             dag_folder=dag_path,
@@ -542,7 +543,7 @@ def make_dagster_pipeline_from_airflow_dag(
                 importlib.reload(airflow)
             if not airflow_initialized:
                 db.initdb()
-                create_airflow_connections(
+                _create_airflow_connections(
                     [Connection(**c) for c in context.resource_config["connections"]]
                 )
 
