@@ -9,7 +9,7 @@ from airflow.exceptions import AirflowException
 from airflow.hooks.base_hook import BaseHook
 from airflow.models import Connection
 
-from dagster._core.storage.pipeline_run import PipelineRunStatus
+from dagster._core.storage.pipeline_run import DagsterRunStatus
 
 
 class DagsterHook(BaseHook):
@@ -213,9 +213,9 @@ fragment PythonErrorFragment on PythonError {
         headers = {"Dagster-Cloud-Api-Token": self.user_token if self.user_token else ""}
         status = ""
         while status not in [
-            PipelineRunStatus.SUCCESS.value,
-            PipelineRunStatus.FAILURE.value,
-            PipelineRunStatus.CANCELED.value,
+            DagsterRunStatus.SUCCESS.value,
+            DagsterRunStatus.FAILURE.value,
+            DagsterRunStatus.CANCELED.value,
         ]:
             response = requests.post(
                 url=self.url, json={"query": query, "variables": variables}, headers=headers
@@ -230,11 +230,11 @@ fragment PythonErrorFragment on PythonError {
                     f'Error fetching run status: {response_json["data"]["runOrError"]["message"]}'
                 )
 
-            if status == PipelineRunStatus.SUCCESS.value:
+            if status == DagsterRunStatus.SUCCESS.value:
                 logging.info(f"Run {run_id} completed successfully")
-            elif status == PipelineRunStatus.FAILURE.value:
+            elif status == DagsterRunStatus.FAILURE.value:
                 raise AirflowException(f"Run {run_id} failed")
-            elif status == PipelineRunStatus.CANCELED.value:
+            elif status == DagsterRunStatus.CANCELED.value:
                 raise AirflowException(f"Run {run_id} was cancelled")
             time.sleep(5)
 
